@@ -23,13 +23,15 @@ Usage::
     search_resources_paginator: SearchResourcesPaginator = client.get_paginator("search_resources")
     ```
 """
-from mypy_boto3_resource_groups.client import ResourceGroupsClient, ResourceGroupsClient as Client
+from mypy_boto3_resource_groups.client import ResourceGroupsClient
 from mypy_boto3_resource_groups.paginator import (
     ListGroupResourcesPaginator,
     ListGroupsPaginator,
     SearchResourcesPaginator,
 )
 
+Client = ResourceGroupsClient
+
 
 __all__ = (
     "Client",
